#!/bin/ash

source /etc/conf.d/network.conf

gen_sysname="`hostname`"
gen_kernel=`uname -sr`
gen_date=`date`
gen_load=`uptime`
gen_load=${gen_load#*average:}
gen_uptime=`uptime`
gen_uptime=${gen_uptime#*up}
gen_uptime=${gen_uptime%, *user*}
gen_uptime=${gen_uptime%*, load*}

mem_used=`free | grep Mem |  awk  '{print $3}'`
mem_used="$mem_used kB"
mem_total=`free | grep Mem |  awk  '{print $2}'`
mem_total="$mem_total kB"
mem_cached=`cat /proc/meminfo | grep Cached | head -1 | awk '{print $2}'`
mem_cached="$mem_cached kB"
mem_buffer=`cat /proc/meminfo | grep Buffer | awk '{print $2}'`
mem_buffer="$mem_buffer kB"
mem_free=`free | grep Mem |  awk  '{print $4}'`
mem_free="$mem_free kB"

cpu_vendor=`cat /proc/cpuinfo | grep type | awk  '{print $4}'`
if [ -z "$cpu_vendor" ] ; then                                  
cpu_vendor=`cat /proc/cpuinfo | grep vendor | awk  '{print $5}'`
fi
if [ -z "$cpu_vendor" ] ; then
cpu_vendor=`cat /proc/cpuinfo | grep vendor | awk  '{print $3}'`
fi
cpu_type=`cat /proc/cpuinfo | grep type | awk '{print $5}'`
if [ -z "$cpu_type" ] ; then                                                                            
cpu_type=`cat /proc/cpuinfo | grep MHz | awk '{print $4}'`
fi
cpu_model=`cat /proc/cpuinfo | grep model | awk '{print $4} {print $5} {print $6}'`
if echo $cpu_model | grep Unknown >/dev/null ; then
cpu_model=`cat /proc/cpuinfo | grep vendor | awk '{print $3}'`
fi
cpu_arch=`uname -m`
cpu_bogo=`cat /proc/cpuinfo | grep ogo | awk  '{print $3}'`

echo ""
if [ -d "/usr" ] ; then
    echo "<div class='big'><img src='pics/livecd.png' alt='livecd' />`hostname` system information:</div>"
else
    echo "<div class='big'><img src='pics/favicon.ico' alt='node' />`hostname` system information:</div>"
fi
echo "<table cellpadding='0' cellspacing='0' >"
echo "<tr>"
echo "<td class='border' colspan='2' align='left' ><strong>General</strong></td>"
echo "<td class='border' colspan='2' align='left' ><strong>CPU</strong></td>"
echo "<td class='border' colspan='2' align='left' ><strong>Memory</strong></td>"
echo "</tr>"
echo "<tr>"
echo "<td class='noside' align='left'>Hostname</td>"
echo "<td class='border' align='right'>${gen_sysname}</td>"
echo "<td class='noside' align='left'>Vendor</td>"
echo "<td class='border' align='right'>${cpu_vendor}</td>"
echo "<td class='noside' align='left'>Total</td>"
echo "<td class='border' align='right'>${mem_total}</td>"
echo "</tr>"
echo "<tr>"
echo "<td class='noside' align='left'>Uptime</td>"
echo "<td class='border' align='right'>${gen_uptime}</td>"
echo "<td class='noside' align='left'>Type/MHz</td>"
echo "<td class='border' align='right'>${cpu_type}</td>"
echo "<td class='noside' align='left'>Used</td>"
echo "<td class='border' align='right'>${mem_used}</td>"
echo "</tr>"
echo "<tr>"
echo "<td class='noside' align='left'>Load</td>"
echo "<td class='border' align='right'>${gen_load}</td>"
echo "<td class='noside' align='left'>Model</td>"
echo "<td class='border' align='right'>${cpu_model}</td>"
echo "<td class='noside' align='left'>Cached</td>"
echo "<td class='border' align='right'>${mem_cached}</td>"
echo "</tr>"
echo "<tr>"
echo "<td class='noside' align='left'>Kernel</td>"
echo "<td class='border' align='right'>${gen_kernel}</td>"
echo "<td class='noside' align='left'>Architecture</td>"
echo "<td class='border' align='right'>${cpu_arch}</td>"
echo "<td class='noside' align='left'>Buffers</td>"
echo "<td class='border' align='right'>${mem_buffer}</td>"
echo "</tr>"
echo "<tr>"
echo "<td class='noside' align='left'>Date</td>"
echo "<td class='border' align='right'>${gen_date}</td>"
echo "<td class='noside' align='left'>BogoMIPS</td>"
echo "<td class='border' align='right'>${cpu_bogo}</td>"
echo "<td class='noside' align='left'>Free</td>"
echo "<td class='border' align='right'>${mem_free}</td>"
echo "</tr>"
echo "</table>"

echo "<br>"
if [ -d "/usr" ] ; then
    echo "<div class='big'><img src='pics/livecd.png' alt='livecd' />`hostname` network settings:</div>"
else
    echo "<div class='big'><img src='pics/favicon.ico' alt='node' />`hostname` network settings:</div>"
fi

echo "<table cellpadding='0' cellspacing='0' >"
echo "<tr>"
echo "<td class='border' colspan='1' align='left' ><strong>Default Route</strong></td>"
echo "<td class='border' colspan='5' align='left' >`ip route | grep default | sed 's/default//'`</td>"
echo "</tr>"
echo "<tr>"
echo "<td class='border' colspan='1' align='left' ><strong>DNS Servers</strong></td>"
echo "<td class='border' colspan='5' align='left' >`cat /etc/resolv.conf | grep nameserver | sed -e 's/nameserver//'`</td>"
echo "</tr>"
echo "<tr>"
echo "<td class='border'><strong>Interface</strong></td>"
echo "<td class='border'><strong>Link State</strong></td>"
echo "<td class='border'><strong>IPv4 Address</strong></td>"
echo "<td class='border'><strong>IPv6 Address</strong></td>"
echo "<td class='border'><strong>Received Bytes/Packets</strong></td>"
echo "<td class='border'><strong>Transmitted Bytes/Packets</strong></td>"
echo "</tr>"

for dev in ${AVAIL_DEVICES} lo ; do
echo "<tr>"
echo "<td align='right' class='border'><strong>${dev}</strong></td>"
if ip link | grep UP | grep ${dev} > /dev/null ; then
    echo "<td align='right' class='border'><strong>Up</strong> `ip addr show dev ${dev} | grep ether | awk '{print $2}'`</td>"
    echo "<td align='right' class='border'>`ip addr show dev ${dev} | grep "inet " | awk '{print $2}'`</td>"
    echo "<td align='right' class='border'>`ip addr show dev ${dev} | grep inet6 | awk '{print $2}'`</td>"
else
    echo "<td align='right' class='border'><strong>Down</strong></td>"
    echo "<td align='right' class='border'> </td>"
    echo "<td align='right' class='border'> </td>"
fi
echo "<td align='right' class='border'>`cat /proc/net/dev | grep " ${dev}" | awk '{print $2}'`/`cat /proc/net/dev | grep " ${dev}" | awk '{print $3}'`</td>"
echo "<td align='right' class='border'>`cat /proc/net/dev | grep " ${dev}" | awk '{print $10}'`/`cat /proc/net/dev | grep " ${dev}" | awk '{print $11}'`</td>"
echo "</tr>"
done

echo "</table>"
echo "<br>"
echo ""
